# scikit-learn-emeralds

Collection of tools for numpy and scikit-learn:

* [Autohist](docs/Example%20usage%20autohist.ipynb) - Split a dataset by frequency of data values
* [Probabalistic confusion
  matrix](docs/Example%20usage%20confusion%20matrix.ipynb) - Generate
  a confusion matrix that takes probabilities/certainty of predictions
  into account
